<article id="{{ instance.slug }}">
  <hgroup>
    <h2><a href="#{{ instance.slug }}">{{ instance.title }}</a></h2>
    {% if instance.description %}<h4 class="subheader">{{ instance.description }}</h4>{% endif %}
  </hgroup>

{{ instance.body|safe }}
</article>
